================================
Review Board 1.5.6 Release Notes
================================


**Release date**: August 20, 2011


New Features
============

* The :envvar:`PATH` environment variable is now shown in the error when
  :command:`patch.exe` can't be found, in order to help figure out where
  it needs to go.

* :command:`rb-site` more clearly informs that an existing database with
  valid permissions is needed for installation.

* :command:`rb-site` now lists recommendations for different services,
  and lists options that aren't officially supported.

* Tabs in the diff viewer are now marked up, allowing custom stylesheets to
  display them differently. By default, they don't look any different.
  Patch by Jan Koprowski.

* Added `Fedora Hosted`_ to the hosting provider options. Patch by
  Stephen Gallagher.

* Editing a field and then canceling it on a review request now prompts
  for confirmation before discarding the new text. (:bug:`2096`)

* :kbd:`Control-S` now saves the current text in review request fields.
  (:bug:`1958`)

* We now support storing lots of text in the Description and Testing Done
  fields on MySQL. (:bug:`1481`)

.. _`Fedora Hosted`: https://fedorahosted.org/


Performance Improvements
========================

* Review Board now requires Pygments 1.4 or higher. Older installations
  running older versions of Pygments should get a performance increase
  when rendering diffs.


Bug Fixes
=========

* Using Review Board with wsgi without mod_python installed on the system
  no longer prevents Review Board from breaking. (:bug:`2023`)

* Screenshot draft captions are now always displayed correctly. Previously,
  only the main caption would display, making them appear blank on new
  uploads.

* Changing screenshot draft captions now invalidates the cache, allowing them
  to be seen when reloading the page.

* When sending an e-mail, we no longer crash if the sender has no e-mail
  address. (:bug:`1943`)

* Caching really long files or diffs now works more consistently. Previously,
  it was possible for the data to not be stored correctly. (:bug:`1660`)

* Fixed a date range calculation sometimes causing the log viewer to fail
  on the first of the month. (:bug:`2218`)

* Failing to load the Review Board News feed in the administration UI due to
  a proxy will no longer cause an HTTP 500 error to display. (:bug:`2189`)

* Invalid bug tracker URLs (those containing more than one ``%s``, for
  example) in the administration UI no longer breaks review requests.

* The Mercurial support no longer overrides the SSH client configuration
  if one is already provided. Patch by Ingo Proetel.

* The ``recaptcha_client`` dependency has been renamed to
  ``recaptcha-client``. Both technically work, but the former is more
  correct and makes packaging easier.

* Fixed a few occasional errors that could show up on the dashboard under
  certain conditions.


Contributors
============

* Christian Hammond
* David Trowbridge
* Ingo Proetel
* Jan Koprowski
* Stephen Gallagher
